BumpFreeListAllocator

Struct BumpFreeListAllocator 

pub struct BumpFreeListAllocator;
Minimal Bump Pointer + Unordered Free List Allocator.

极简 Bump Pointer + 无序链表分配器。

Features

  • Extreme Size: Removes binning and merging logic to minimize code size.
  • Fast Startup: No initialization overhead.
  • Fragmentation: Does not merge memory, long-running processes will cause OOM. Only suitable for short-lived tasks.

特性

  • 极致体积:移除分箱和合并逻辑,代码量最小化。
  • 快速启动:无初始化开销。
  • 碎片化:不合并内存,长期运行会导致 OOM。仅适用于短生命周期任务。

Implementations

Source

impl BumpFreeListAllocator

pub const fn new() -> Self

Source

impl BumpFreeListAllocator

pub unsafe fn reset()

Testing only: Reset the internal state. Safety: usage is inherently unsafe if allocator is in use.

仅测试用:重置内部状态。 安全性:如果分配器正在使用,未定义的行为。