FreeListAllocator

Struct FreeListAllocator 

pub struct FreeListAllocator;
A non-thread-safe allocator using a free list. Complexity of allocation and deallocation is O(length of free list).

The free list is sorted by address, and adjacent memory blocks are merged when inserting new blocks.

一个使用空闲链表的非线程安全分配器。 分配和释放操作的时间复杂度为 O(空闲链表长度)。

空闲链表按地址排序,并且在插入新块时会合并相邻的内存块。

Implementations

Source

impl FreeListAllocator

pub const fn new() -> Self

pub unsafe fn reset()

Testing only: Reset the internal state. Safety: usage is inherently unsafe if allocator is in use.